@@ -2,7 +2,7 @@
 from __future__ import annotations
 import copyreg
 from .pretty import pretty
-from typing import Any, Iterator, Hashable, Optional, Pattern, Iterable, Mapping
+from typing import Any, Iterator, Hashable, Pattern, Iterable, Mapping
 
 __all__ = (
     'Selector',
@@ -45,11 +45,11 @@ class Immutable:
         for k, v in kwargs.items():
             temp.append(type(v))
             temp.append(v)
-            super(Immutable, self).__setattr__(k, v)
-        super(Immutable, self).__setattr__('_hash', hash(tuple(temp)))
+            super().__setattr__(k, v)
+        super().__setattr__('_hash', hash(tuple(temp)))
 
     @classmethod
-    def __base__(cls) -> "type[Immutable]":
+    def __base__(cls) -> type[Immutable]:
         """Get base class."""
 
         return cls
@@ -59,7 +59,7 @@ class Immutable:
 
         return (
             isinstance(other, self.__base__()) and
-            all([getattr(other, key) == getattr(self, key) for key in self.__slots__ if key != '_hash'])
+            all(getattr(other, key) == getattr(self, key) for key in self.__slots__ if key != '_hash')
         )
 
     def __ne__(self, other: Any) -> bool:
@@ -67,7 +67,7 @@ class Immutable:
 
         return (
             not isinstance(other, self.__base__()) or
-            any([getattr(other, key) != getattr(self, key) for key in self.__slots__ if key != '_hash'])
+            any(getattr(other, key) != getattr(self, key) for key in self.__slots__ if key != '_hash')
         )
 
     def __hash__(self) -> int:
@@ -78,14 +78,13 @@ class Immutable:
     def __setattr__(self, name: str, value: Any) -> None:
         """Prevent mutability."""
 
-        raise AttributeError("'{}' is immutable".format(self.__class__.__name__))
+        raise AttributeError(f"'{self.__class__.__name__}' is immutable")
 
     def __repr__(self) -> str:  # pragma: no cover
         """Representation."""
 
-        return "{}({})".format(
-            self.__class__.__name__, ', '.join(["{}={!r}".format(k, getattr(self, k)) for k in self.__slots__[:-1]])
-        )
+        r = ', '.join([f"{k}={getattr(self, k)!r}" for k in self.__slots__[:-1]])
+        return f"{self.__class__.__name__}({r})"
 
     __str__ = __repr__
 
@@ -112,10 +111,10 @@ class ImmutableDict(Mapping[Any, Any]):
         """Validate arguments."""
 
         if isinstance(arg, dict):
-            if not all([isinstance(v, Hashable) for v in arg.values()]):
-                raise TypeError('{} values must be hashable'.format(self.__class__.__name__))
-        elif not all([isinstance(k, Hashable) and isinstance(v, Hashable) for k, v in arg]):
-            raise TypeError('{} values must be hashable'.format(self.__class__.__name__))
+            if not all(isinstance(v, Hashable) for v in arg.values()):
+                raise TypeError(f'{self.__class__.__name__} values must be hashable')
+        elif not all(isinstance(k, Hashable) and isinstance(v, Hashable) for k, v in arg):
+            raise TypeError(f'{self.__class__.__name__} values must be hashable')
 
     def __iter__(self) -> Iterator[Any]:
         """Iterator."""
@@ -140,7 +139,7 @@ class ImmutableDict(Mapping[Any, Any]):
     def __repr__(self) -> str:  # pragma: no cover
         """Representation."""
 
-        return "{!r}".format(self._d)
+        return f"{self._d!r}"
 
     __str__ = __repr__
 
@@ -156,11 +155,11 @@ class Namespaces(ImmutableDict):
     def _validate(self, arg: dict[str, str] | Iterable[tuple[str, str]]) -> None:
         """Validate arguments."""
 
-        if isinstance(arg, dict):
-            if not all([isinstance(v, str) for v in arg.values()]):
-                raise TypeError('{} values must be hashable'.format(self.__class__.__name__))
-        elif not all([isinstance(k, str) and isinstance(v, str) for k, v in arg]):
-            raise TypeError('{} keys and values must be Unicode strings'.format(self.__class__.__name__))
+        if not all(
+            isinstance(k, str) and isinstance(v, str)
+            for k, v in (arg.items() if isinstance(arg, dict) else arg)
+        ):
+            raise TypeError(f'{self.__class__.__name__} values must be hashable')
 
 
 class CustomSelectors(ImmutableDict):
@@ -174,11 +173,11 @@ class CustomSelectors(ImmutableDict):
     def _validate(self, arg: dict[str, str] | Iterable[tuple[str, str]]) -> None:
         """Validate arguments."""
 
-        if isinstance(arg, dict):
-            if not all([isinstance(v, str) for v in arg.values()]):
-                raise TypeError('{} values must be hashable'.format(self.__class__.__name__))
-        elif not all([isinstance(k, str) and isinstance(v, str) for k, v in arg]):
-            raise TypeError('{} keys and values must be Unicode strings'.format(self.__class__.__name__))
+        if not all(
+            isinstance(k, str) and isinstance(v, str)
+            for k, v in (arg.items() if isinstance(arg, dict) else arg)
+        ):
+            raise TypeError(f'{self.__class__.__name__} values must be hashable')
 
 
 class Selector(Immutable):
@@ -189,28 +188,28 @@ class Selector(Immutable):
         'relation', 'rel_type', 'contains', 'lang', 'flags', '_hash'
     )
 
-    tag: Optional[SelectorTag]
+    tag: SelectorTag | None
     ids: tuple[str, ...]
     classes: tuple[str, ...]
     attributes: tuple[SelectorAttribute, ...]
     nth: tuple[SelectorNth, ...]
     selectors: tuple[SelectorList, ...]
     relation: SelectorList
-    rel_type: Optional[str]
+    rel_type: str | None
     contains: tuple[SelectorContains, ...]
     lang: tuple[SelectorLang, ...]
     flags: int
 
     def __init__(
         self,
-        tag: Optional[SelectorTag],
+        tag: SelectorTag | None,
         ids: tuple[str, ...],
         classes: tuple[str, ...],
         attributes: tuple[SelectorAttribute, ...],
         nth: tuple[SelectorNth, ...],
         selectors: tuple[SelectorList, ...],
         relation: SelectorList,
-        rel_type: Optional[str],
+        rel_type: str | None,
         contains: tuple[SelectorContains, ...],
         lang: tuple[SelectorLang, ...],
         flags: int
@@ -247,9 +246,9 @@ class SelectorTag(Immutable):
     __slots__ = ("name", "prefix", "_hash")
 
     name: str
-    prefix: Optional[str]
+    prefix: str | None
 
-    def __init__(self, name: str, prefix: Optional[str]) -> None:
+    def __init__(self, name: str, prefix: str | None) -> None:
         """Initialize."""
 
         super().__init__(name=name, prefix=prefix)
@@ -262,15 +261,15 @@ class SelectorAttribute(Immutable):
 
     attribute: str
     prefix: str
-    pattern: Optional[Pattern[str]]
-    xml_type_pattern: Optional[Pattern[str]]
+    pattern: Pattern[str] | None
+    xml_type_pattern: Pattern[str] | None
 
     def __init__(
         self,
         attribute: str,
         prefix: str,
-        pattern: Optional[Pattern[str]],
-        xml_type_pattern: Optional[Pattern[str]]
+        pattern: Pattern[str] | None,
+        xml_type_pattern: Pattern[str] | None
     ) -> None:
         """Initialize."""
 
@@ -360,14 +359,14 @@ class SelectorList(Immutable):
 
     def __init__(
         self,
-        selectors: Optional[Iterable[Selector | SelectorNull]] = None,
+        selectors: Iterable[Selector | SelectorNull] | None = None,
         is_not: bool = False,
         is_html: bool = False
     ) -> None:
         """Initialize."""
 
         super().__init__(
-            selectors=tuple(selectors) if selectors is not None else tuple(),
+            selectors=tuple(selectors) if selectors is not None else (),
             is_not=is_not,
             is_html=is_html
         )
